@@ -1,3 +1,4 @@
+import functools
 import re
 from importlib.metadata import Distribution
 from pathlib import Path
@@ -11,20 +12,22 @@ from unearth import Link
 from pdm_conda.models.requirements import (
     CondaRequirement,
     Requirement,
+    parse_conda_version,
     parse_requirement,
 )
 from pdm_conda.models.setup import CondaSetupDistribution
 
+_patched = False
+
 
 class CondaPreparedCandidate(PreparedCandidate):
     def __init__(self, candidate: Candidate, environment: Environment) -> None:
         super().__init__(candidate, environment)
         self.candidate = cast(CondaCandidate, self.candidate)  # type: ignore
-        self.req = cast(CondaRequirement, self.req)  # type: ignore
 
     def get_dependencies_from_metadata(self) -> list[str]:
         # if conda candidate return already obtained dependencies
-        return [d.as_line() for d in self.candidate.dependencies]
+        return [d.as_line(as_conda=True, with_build_string=True) for d in self.candidate.dependencies]
 
     def prepare_metadata(self) -> Distribution:
         # if conda candidate get setup from package
@@ -40,16 +43,17 @@ class CondaCandidate(Candidate):
         link: Link | None = None,
         dependencies: list[str] | None = None,
         build_string: str | None = None,
+        channel: str | None = None,
     ):
         super().__init__(req, name, version, link)
-        # extract hash from link
-        if link and link.hash is not None:
-            self.hashes = {link: link.hash}
         self._req = cast(CondaRequirement, req)  # type: ignore
         self._preferred = None
         self._prepared: CondaPreparedCandidate | None = None
-        self.dependencies = [parse_requirement(f"conda:{r}") for r in (dependencies or [])]
+        self.dependencies: list[CondaRequirement] = [parse_requirement(f"conda:{r}") for r in (dependencies or [])]
         self.build_string = build_string
+        self.channel = channel
+        self.conda_version = version
+        self.version = parse_conda_version(version)
 
     @property
     def req(self):
@@ -67,7 +71,7 @@ class CondaCandidate(Candidate):
                 name=self.name,
                 summary="",
                 version=self.version,
-                install_requires=[d.as_line() for d in self.dependencies],
+                install_requires=[d.as_line(as_conda=True, with_build_string=True) for d in self.dependencies],
                 python_requires=self.requires_python,
             ),
         )
@@ -75,13 +79,13 @@ class CondaCandidate(Candidate):
     def as_lockfile_entry(self, project_root: Path) -> dict[str, Any]:
         result = super().as_lockfile_entry(project_root)
         result["conda_managed"] = True
-        if self.req.channel is not None:
-            result["channel"] = self.req.channel
         if self.link is None:
             raise ValueError("Uninitialized conda requirement")
         result["url"] = self.link.url
-        if self.link.comes_from is not None:
-            result["channel_url"] = self.link.comes_from
+        result["channel"] = self.channel
+        if self.build_string is not None:
+            result["build_string"] = self.build_string
+        result["version"] = self.conda_version
         return result
 
     def prepare(self, environment: Environment) -> CondaPreparedCandidate:
@@ -104,9 +108,7 @@ class CondaCandidate(Candidate):
         return CondaCandidate.from_conda_package(
             package
             | {
-                "channel": package.get("channel_url", None),
                 "depends": dependencies,
-                "build_string": None,
             },
         )
 
@@ -133,12 +135,36 @@ class CondaCandidate(Candidate):
         url = package["url"]
         for k, v in hashes.items():
             url += f"#{k}={v}"
-        name, version = package["name"], package["version"]
+        name, version, build_string = package["name"], package["version"], package.get("build_string", "")
+        channel = package["channel"]
+        req = parse_requirement(f"conda:{name} {version} {build_string}")
+        req.is_python_package = requires_python is not None
         return CondaCandidate(
-            req=parse_requirement(f"conda:{name} {version}"),
+            req=req,
             name=name,
             version=version,
-            link=Link(url, comes_from=package["channel"], requires_python=requires_python, hashes=hashes),
+            link=Link(
+                url,
+                requires_python=requires_python,
+                comes_from=channel,
+            ),
+            channel=channel,
             dependencies=dependencies,
-            build_string=package["build_string"],
+            build_string=build_string,
         )
+
+
+def wrap_as_lockfile_entry(func):
+    @functools.wraps(func)
+    def wrapper(self, *args, **kwargs) -> dict[str, Any]:
+        res = func(self, *args, **kwargs)
+        if (conda_name := self.req.conda_name) is not None and conda_name != self.name:
+            res["conda_name"] = conda_name
+        return res
+
+    return wrapper
+
+
+if not _patched:
+    setattr(Candidate, "as_lockfile_entry", wrap_as_lockfile_entry(Candidate.as_lockfile_entry))
+    _patched = True
