@@ -3,20 +3,21 @@ import subprocess
 from functools import lru_cache
 from tempfile import NamedTemporaryFile, TemporaryDirectory
 from typing import cast
+from urllib.parse import urlparse
 
 from pdm.exceptions import RequirementError
-from pdm.models.requirements import strip_extras
 from pdm.models.setup import Setup
 from pdm.project import Project
 
 from pdm_conda.models.candidates import CondaCandidate
-from pdm_conda.models.config import PluginConfig
 from pdm_conda.models.requirements import (
     CondaRequirement,
     Requirement,
+    parse_conda_version,
     parse_requirement,
 )
 from pdm_conda.models.setup import CondaSetupDistribution
+from pdm_conda.project import CondaProject
 from pdm_conda.utils import normalize_name
 
 
@@ -62,32 +63,24 @@ def run_conda(cmd, **environment) -> dict:
     return response
 
 
-@lru_cache
-def conda_search(
-    requirement: CondaRequirement | str,
-    project: Project,
-    channel: str | None = None,
+@lru_cache(maxsize=None)
+def _conda_search(
+    requirement: str,
+    project: CondaProject,
+    channels: tuple[str],
 ) -> list[CondaCandidate]:
     """
     Search conda candidates for a requirement
     :param requirement: requirement
     :param project: PDM project
-    :param channel: requirement channel
+    :param channels: requirement channels
     :return: list of conda candidates
     """
-    from pdm_conda.project import CondaProject
-
-    config = PluginConfig.load_config(project)
-    command = config.command("search")
-    project = cast(CondaProject, project)
+    command = project.conda_config.command("search")
     if not project.virtual_packages:
         project.virtual_packages = conda_virtual_packages(project)
 
-    if isinstance(requirement, CondaRequirement):
-        channel = channel or requirement.channel
-        requirement = requirement.as_line()
     command.append(requirement)
-    channels = [channel] if channel else config.channels
     for c in channels:
         command.extend(["-c", c])
     command.append("--json")
@@ -103,11 +96,40 @@ def conda_search(
                     valid_candidate = False
                     break
         if valid_candidate:
+            package_channel = urlparse(p["channel"]).path
+            for c in channels:
+                if c in package_channel:
+                    p["channel"] = c
+                    break
+            if "defaults" in channels and p["channel"].startswith("http"):
+                p["channel"] = "defaults"
+
             candidates.append(CondaCandidate.from_conda_package(p))
 
     return candidates
 
 
+def conda_search(
+    requirement: CondaRequirement | str,
+    project: CondaProject,
+    channel: str | None = None,
+) -> list[CondaCandidate]:
+    """
+    Search conda candidates for a requirement
+    :param requirement: requirement
+    :param project: PDM project
+    :param channel: requirement channel
+    :return: list of conda candidates
+    """
+    if isinstance(requirement, CondaRequirement):
+        channel = channel or requirement.channel
+        requirement = requirement.as_line(with_build_string=True).replace(" ", "=")
+    if "::" in requirement:
+        channel, requirement = requirement.split("::", maxsplit=1)
+    channels = [channel] if channel else (project.conda_config.channels or ["defaults"])
+    return _conda_search(requirement, project, tuple(channels))
+
+
 def update_requirements(requirements: list[Requirement], conda_packages: dict[str, CondaCandidate]):
     """
     Update requirements list with conda_packages
@@ -116,9 +138,8 @@ def update_requirements(requirements: list[Requirement], conda_packages: dict[st
     """
     repeated_packages: dict[str, int] = dict()
     for i, requirement in enumerate(requirements):
-        name, _ = strip_extras(requirement.name)
-        if name in conda_packages:
-            requirement.extras = None
+        if (name := requirement.conda_name) in conda_packages and not isinstance(requirement, CondaRequirement):
+            requirement.name = requirement.conda_name
             requirements[i] = parse_requirement(f"conda:{requirement.as_line()}")
         repeated_packages[name] = repeated_packages.get(name, 0) + 1
     to_remove = []
@@ -136,48 +157,60 @@ def lock_conda_dependencies(project: Project, requirements: list[Requirement], *
     :param project: PDM project
     :param requirements: requirements list
     """
-    config = PluginConfig.load_config(project)
-    _requirements = [r.as_line() for r in requirements if isinstance(r, CondaRequirement)]
+    project = cast(CondaProject, project)
+    config = project.conda_config
+    if not config.is_initialized:
+        return
+
+    _requirements = [r for r in requirements if isinstance(r, CondaRequirement)]
     if 0 < len(_requirements) < len(requirements):
-        _requirements.insert(0, f"python=={project.python.version}")
+        python_req = f"python=={project.python.version}"
+        working_set = conda_list(project)
+        if "python" in working_set:
+            python_req = working_set["python"].as_line()
+        _requirements.insert(0, parse_requirement(f"conda:{python_req}"))
         with TemporaryDirectory() as d:
             prefix = f"{d}/env"
             run_conda(config.command("create") + ["--prefix", prefix, "--json"])
             project.core.ui.echo(f"Created temporary environment at {prefix}")
             try:
-                conda_packages = conda_lock(project, _requirements, prefix, config)
+                conda_packages = conda_lock(project, _requirements, prefix)
             finally:
                 run_conda(config.command("remove") + ["--prefix", prefix, "--json"])
                 project.core.ui.echo(f"Removed temporary environment at {prefix}")
-        update_requirements(requirements, conda_packages)
+    else:
+        conda_packages = {}
+        for r in _requirements:
+            candidate = conda_search(r, project)[0]
+            conda_packages[candidate.name] = candidate
+
+    update_requirements(requirements, conda_packages)
 
 
 def conda_lock(
-    project: Project,
-    requirements: list[str],
+    project: CondaProject,
+    requirements: list[CondaRequirement],
     prefix: str,
-    config: PluginConfig | None = None,
 ) -> dict[str, CondaCandidate]:
     """
     Resolve conda marked requirements
     :param project: PDM project
     :param requirements: list of requirements
     :param prefix: environment prefix
-    :param config: plugin config
     :return: resolved packages
     """
     packages: dict[str, CondaCandidate] = dict()
-    if config is None:
-        config = PluginConfig.load_config(project)
+    config = project.conda_config
     core = project.core
     if not requirements:
         return packages
 
-    core.ui.echo("Using conda to get: " + " ".join([r for r in requirements if not r.startswith("python==")]))
+    core.ui.echo("Using conda to get: " + " ".join([r.as_line() for r in requirements if r.name != "python"]))
+    _requirements = [r.as_line(with_build_string=True, with_channel=True).replace(" ", "=") for r in requirements]
     response = run_conda(
         config.command() + ["--force-reinstall", "--json", "--dry-run", "--prefix", prefix],
-        channels=config.channels,
-        dependencies=requirements,
+        channels=config.channels or ["defaults"],
+        dependencies=_requirements,
     )
 
     if "actions" in response:
@@ -192,7 +225,7 @@ def conda_lock(
 
 
 def _conda_install(
-    project: Project,
+    project: CondaProject,
     command: list[str],
     packages: str | list[str] | None = None,
     verbose: bool = False,
@@ -208,9 +241,8 @@ def _conda_install(
 
 
 def conda_install(
-    project: Project,
+    project: CondaProject,
     packages: str | list[str],
-    config: PluginConfig | None = None,
     verbose: bool = False,
     dry_run: bool = False,
     no_deps: bool = False,
@@ -219,13 +251,11 @@ def conda_install(
     Install resolved packages using conda
     :param project: PDM project
     :param packages: resolved packages
-    :param config: plugin config
     :param verbose: show conda response if true
     :param dry_run: don't install if dry run
     :param no_deps: don't install dependencies if true
     """
-
-    config = config or PluginConfig.load_config(project)
+    config = project.conda_config
     command = config.command()
     if no_deps:
         command.append("--no-deps")
@@ -236,9 +266,8 @@ def conda_install(
 
 
 def conda_uninstall(
-    project: Project,
+    project: CondaProject,
     packages: str | list[str],
-    config: PluginConfig | None = None,
     verbose: bool = False,
     dry_run: bool = False,
     no_deps: bool = False,
@@ -247,13 +276,11 @@ def conda_uninstall(
     Uninstall resolved packages using conda
     :param project: PDM project
     :param packages: resolved packages
-    :param config: plugin config
     :param verbose: show conda response if true
     :param dry_run: don't uninstall if dry run
     :param no_deps: don't uninstall dependencies if true
     """
-
-    config = config or PluginConfig.load_config(project)
+    config = project.conda_config
     command = config.command("remove")
     if no_deps:
         command.append("--no-prune")
@@ -267,13 +294,13 @@ def conda_uninstall(
     _conda_install(project, command, verbose=verbose)
 
 
-def conda_virtual_packages(project: Project) -> set[str]:
+def conda_virtual_packages(project: CondaProject) -> set[str]:
     """
     Get conda virtual packages
     :param project: PDM project
     :return: set of virtual packages
     """
-    config = PluginConfig.load_config(project)
+    config = project.conda_config
     virtual_packages = []
     if config.is_initialized:
         info = run_conda(config.command("info") + ["--json"])
@@ -281,25 +308,25 @@ def conda_virtual_packages(project: Project) -> set[str]:
     return set(virtual_packages)
 
 
-def conda_list(project: Project) -> dict[str, CondaSetupDistribution]:
+def conda_list(project: CondaProject) -> dict[str, CondaSetupDistribution]:
     """
     List conda installed packages
     :param project: PDM project
     :return: packages distribution
     """
-    config = PluginConfig.load_config(project)
+    config = project.conda_config
     distributions = dict()
     if config.is_initialized:
         packages = run_conda(config.command("list") + ["--json"])
         for package in packages:
-            name = package["name"]
+            name, version = package["name"], package["version"]
             distributions[normalize_name(name)] = CondaSetupDistribution(
                 Setup(
                     name=name,
                     summary="",
-                    version=package["version"],
+                    version=parse_conda_version(version),
                 ),
-                extras=package,
+                package=package,
             )
 
     return distributions
