@@ -2,17 +2,16 @@ from pathlib import Path
 from typing import cast
 
 from pdm.core import Core
-from pdm.exceptions import PdmUsageError, ProjectError
+from pdm.exceptions import ProjectError
+from pdm.models.environment import Environment
+from pdm.models.repositories import LockedRepository
+from pdm.models.specifiers import PySpecSet
 from pdm.project import Project
+from pdm.utils import get_venv_like_prefix
 from tomlkit.items import Array
 
-from pdm_conda.installers.manager import CondaInstallManager
-from pdm_conda.installers.synchronizers import CondaSynchronizer
-from pdm_conda.models.repositories import (
-    LockedCondaRepository,
-    LockedRepository,
-    PyPICondaRepository,
-)
+from pdm_conda.mapping import pypi_to_conda
+from pdm_conda.models.config import PluginConfig
 from pdm_conda.models.requirements import (
     CondaRequirement,
     NamedRequirement,
@@ -29,56 +28,72 @@ class CondaProject(Project):
         is_global: bool = False,
         global_config: str | Path | None = None,
     ) -> None:
+        from pdm_conda.installers.manager import CondaInstallManager
+        from pdm_conda.installers.synchronizers import CondaSynchronizer
+        from pdm_conda.models.environment import CondaEnvironment
+        from pdm_conda.models.repositories import (
+            LockedCondaRepository,
+            PyPICondaRepository,
+        )
+
         super().__init__(core, root_path, is_global, global_config)
         self.core.repository_class = PyPICondaRepository
         self.core.install_manager_class = CondaInstallManager
-        self.locked_repository_class = LockedCondaRepository
         self.core.synchronizer_class = CondaSynchronizer
+        self.locked_repository_class = LockedCondaRepository
+        self.environment_class = CondaEnvironment
         self.virtual_packages: set[str] = set()
+        self._conda_mapping: dict[str, str] = dict()
+        self._pypi_mapping: dict[str, str] = dict()
+        self.conda_config = PluginConfig.load_config(self)
+
+    def get_conda_pyproject_dependencies(self, group: str, dev: bool = False) -> list[str]:
+        """
+        Get the conda dependencies array in the pyproject.toml
+        """
+        settings = self.pyproject.settings.setdefault("conda", dict())
+        if group == "default":
+            deps = settings.setdefault("dependencies", [])
+        else:
+            name = "optional" if not dev else "dev"
+            deps = settings.setdefault(f"{name}-dependencies", dict()).setdefault(group, [])
+        return deps
 
     def get_dependencies(self, group: str | None = None) -> dict[str, Requirement]:
         result = super().get_dependencies(group)
 
-        settings = self.pyproject.settings.get("conda", {})
+        config = self.conda_config
         group = group or "default"
-        optional_dependencies = settings.get("optional-dependencies", {})
-        dev_dependencies = settings.get("dev-dependencies", {})
-        deps = []
 
-        if group == "default":
-            deps = settings.get("dependencies", [])
-        else:
-            if group in optional_dependencies and group in dev_dependencies:
-                self.core.ui.echo(
-                    f"The {group} group exists in both [optional-dependencies] "
-                    "and [dev-dependencies], the former is taken.",
-                    err=True,
-                    style="warning",
-                )
-            if group in optional_dependencies:
-                deps = optional_dependencies[group]
-            elif group in dev_dependencies:
-                deps = dev_dependencies[group]
-            elif not result:
-                raise PdmUsageError(f"Non-exist group {group}")
+        dev = group not in config.optional_dependencies
+        if group in config.optional_dependencies and group in config.dev_dependencies:
+            self.core.ui.echo(
+                f"The {group} group exists in both [optional-dependencies] "
+                "and [dev-dependencies], the former is taken.",
+                err=True,
+                style="warning",
+            )
+        deps = self.get_conda_pyproject_dependencies(group, dev)
 
         for line in deps:
             req = parse_requirement(f"conda:{line}")
             # search for package with extras to remove it
-            pypi_req = next((v for v in result.values() if v.name == req.name), None)
+            pypi_req = next((v for v in result.values() if v.conda_name == req.conda_name), None)
             if pypi_req is not None:
                 result.pop(pypi_req.identify())
                 if not req.specifier:
                     req.specifier = pypi_req.specifier
             result[req.identify()] = req
 
-        if self.pyproject.settings.get("conda", {}).get("as_default_manager", False):
+        if self.conda_config.as_default_manager:
             for k in list(result):
                 req = result[k]
-                if isinstance(req, NamedRequirement):
+                if isinstance(req, NamedRequirement) and not isinstance(req, CondaRequirement):
                     result.pop(k)
                     req.extras = None
+                    req.name = pypi_to_conda(req.name)
                     result[k] = parse_requirement(f"conda:{req.as_line()}")
+
         return result
 
     @property
@@ -90,16 +105,6 @@ class CondaProject(Project):
 
         return self.locked_repository_class(lockfile, self.sources, self.environment)
 
-    def get_conda_pyproject_dependencies(self, group: str, dev: bool = False) -> list[str]:
-        """
-        Get the conda dependencies array in the pyproject.toml
-        """
-        settings = self.pyproject.settings.setdefault("conda", dict())
-        if group == "default":
-            return settings.setdefault("dependencies", [])
-        name = "optional" if not dev else "dev"
-        return settings.setdefault(f"{name}-dependencies", dict()).setdefault(group, [])
-
     def add_dependencies(
         self,
         requirements: dict[str, Requirement],
@@ -118,8 +123,23 @@ class CondaProject(Project):
                     deps.append(req)
                 else:
                     deps[matched_index] = req
+            self.conda_config.reload()
 
         requirements = {n: r for n, r in requirements.items() if n not in conda_requirements} | {
             n: r.as_named_requirement() for n, r in conda_requirements.items() if r.is_python_package
         }
         super().add_dependencies(requirements, to_group, dev, show_message)
+
+    def get_environment(self) -> Environment:
+        if not self.config["python.use_venv"]:
+            raise ProjectError("python.use_venv is required to use Conda.")
+        if get_venv_like_prefix(self.python.executable) is None:
+            raise ProjectError("Conda environment not detected.")
+
+        env = self.environment_class(self)
+        if self.is_global:
+            # Rewrite global project's python requires to be
+            # compatible with the exact version
+            env.python_requires = PySpecSet(f"=={self.python.version}")
+
+        return env
