@@ -1,7 +1,10 @@
 """Configuration for the pytest test suite."""
+import sys
+from copy import deepcopy
 from tempfile import TemporaryDirectory
 
 import pytest
+import responses
 from pdm.cli.actions import do_init
 from pdm.core import Core
 from pdm.project import Project
@@ -29,10 +32,11 @@ def project(core, distributions) -> Project:
             _project,
             name="test",
             version="0.0.0",
-            python_requires=">=3.10",
+            python_requires=f"=={PYTHON_VERSION}",
             author="test",
             email="test@test.com",
         )
+        _project.global_config["check_update"] = False
         yield _project
 
 
@@ -49,11 +53,16 @@ def mock_conda(mocker, conda_response: dict | list, empty_conda_list):
     def _mock(cmd, **kwargs):
         subcommand = cmd[1]
         if subcommand == "install":
-            return install_response
+            return deepcopy(install_response)
         elif subcommand == "list":
+            python_packages = {p["name"] for p in PYTHON_REQUIREMENTS}
+            res = deepcopy(conda_response)
             if empty_conda_list:
-                return []
-            return conda_response
+                res = [c for c in res if c["name"] in python_packages]
+            for p in res:
+                if p["channel"].startswith("http"):
+                    p["channel"] = p["channel"].split("/")[-1]
+            return res
         elif subcommand == "info":
             return {
                 "virtual packages": [
@@ -66,38 +75,54 @@ def mock_conda(mocker, conda_response: dict | list, empty_conda_list):
         elif subcommand == "search":
             name = next(filter(lambda x: not x.startswith("-"), cmd[2:]))
             name = name.split(">")[0].split("<")[0].split("=")[0].split("~")[0]
-            return {"result": {"pkgs": [p for p in conda_response if p["name"] == name]}}
+            return {"result": {"pkgs": [deepcopy(p) for p in conda_response if p["name"] == name]}}
         else:
             return {"message": "ok"}
 
     yield mocker.patch("pdm_conda.plugin.run_conda", side_effect=_mock)
 
 
+@pytest.fixture
+def mocked_responses():
+    with responses.RequestsMock() as rsps:
+        yield rsps
+
+
+@pytest.fixture
+def mock_conda_mapping(mocker, mocked_responses, conda_mapping):
+    yield mocker.patch("pdm_conda.mapping.download_mapping", return_value=conda_mapping)
+    from pdm_conda.mapping import get_pypi_mapping
+
+    get_pypi_mapping.cache_clear()
+
+
+PYTHON_VERSION = sys.version.split(" ")[0]
+REPO_BASE = "https://anaconda.org"
 PYTHON_REQUIREMENTS = [
     {
         "name": "lib2",
         "depends": [],
-        "version": "1.0.0",
-        "url": "https://channel.com/lib2",
-        "channel": "https://channel.com",
+        "version": "1.0.0g",
+        "url": f"{REPO_BASE}/channel/lib2",
+        "channel": f"{REPO_BASE}/channel",
         "sha256": "this-is-a-hash",
         "build_string": "lib2",
     },
     {
         "name": "lib",
-        "depends": ["lib2 ==1.0.0"],
+        "depends": ["lib2 ==1.0.0g"],
         "version": "1.0.0",
-        "url": "https://channel.com/lib",
-        "channel": "https://channel.com",
+        "url": f"{REPO_BASE}/channel/lib",
+        "channel": f"{REPO_BASE}/channel",
         "sha256": "this-is-a-hash",
         "build_string": "lib",
     },
     {
         "name": "python",
         "depends": ["lib ==1.0.0"],
-        "version": "3.10.9",
-        "url": "https://channel.com/python",
-        "channel": "https://channel.com",
+        "version": PYTHON_VERSION,
+        "url": f"{REPO_BASE}/channel/python",
+        "channel": f"{REPO_BASE}/channel",
         "sha256": "this-is-a-hash",
         "build_string": "python",
     },
@@ -109,20 +134,22 @@ CONDA_INFO = [
         {
             "name": "another-dep",
             "depends": [],
-            "version": "1.0.0",
-            "url": "https://channel.com/another-dep",
-            "channel": "https://channel.com",
+            "version": "1.0.0gg",
+            "url": f"{REPO_BASE}/channel/another-dep",
+            "channel": f"{REPO_BASE}/channel",
             "sha256": "this-is-a-hash",
             "build_string": "another-dep",
         },
         {
             "name": "dep",
-            "depends": ["python >=3.7", "another-dep ==1.0.0"],
+            "depends": ["python >=3.7", "another-dep ==1.0.0gg"],
             "version": "1.0.0",
-            "url": "https://channel.com/dep",
-            "channel": "https://channel.com",
+            "url": f"{REPO_BASE}/channel/dep",
+            "channel": f"{REPO_BASE}/channel",
             "sha256": "this-is-a-hash",
             "build_string": "dep",
         },
     ],
 ]
+
+CONDA_MAPPING = [{f"{p['name']}-pip": p["name"] for p in CONDA_INFO[0] if p not in PYTHON_REQUIREMENTS}]
