@@ -2,7 +2,7 @@ from typing import cast
 
 import pytest
 
-from tests.conftest import CONDA_INFO, PYTHON_REQUIREMENTS
+from tests.conftest import CONDA_INFO, CONDA_MAPPING, PYTHON_REQUIREMENTS
 
 
 class TestAddRemove:
@@ -13,24 +13,17 @@ class TestAddRemove:
     @pytest.mark.parametrize("packages", [["dep"], ["dep", "another-dep"], ["channel::dep", "another-dep"]])
     @pytest.mark.parametrize("channel", [None, "another_channel"])
     @pytest.mark.parametrize("runner", [None, "micromamba"])
-    def test_add(self, core, project, mock_conda, conda_response, packages, channel, runner):
+    @pytest.mark.parametrize("conda_mapping", CONDA_MAPPING)
+    def test_add(self, core, project, mock_conda, conda_response, packages, channel, runner, mock_conda_mapping):
         """
         Test `add` command work as expected
         """
-        from pdm_conda.models.config import PluginConfig
         from pdm_conda.project import CondaProject
 
-        project.pyproject._data.update(
-            {
-                "tool": {
-                    "pdm": {
-                        "conda": {
-                            "runner": runner or self.conda_runner,
-                        },
-                    },
-                },
-            },
-        )
+        project = cast(CondaProject, project)
+        conf = project.conda_config
+        conf.runner = runner or self.conda_runner
+        conf.channels = []
         command = ["add", "-v", "--no-self", "--no-sync"]
         for package in packages:
             command.extend(["--conda", package])
@@ -47,19 +40,16 @@ class TestAddRemove:
         if channel:
             channels.add(channel)
 
-        conf = PluginConfig.load_config(project)
-
         assert channels.issubset(conf.channels)
         assert conf.runner == runner
 
-        num_search = 1  # add conda info
+        num_search = 2 + len(PYTHON_REQUIREMENTS)  # add conda info, list and python packages
         packages_names = {p.split("::")[-1] for p in packages}
         for c in conda_response:
             if c["name"] in packages_names:
-                num_search += 1 + len(c["depends"])
+                num_search += 1 + len([d for d in c["depends"] if not d.startswith("python ")])
         assert mock_conda.call_count == num_search
 
-        project = cast(CondaProject, project)
         dependencies = project.get_conda_pyproject_dependencies("default")
         for package in packages:
             _package = package.split("::")[-1]
@@ -68,14 +58,15 @@ class TestAddRemove:
     @pytest.mark.parametrize("conda_response", CONDA_INFO)
     @pytest.mark.parametrize("empty_conda_list", [False])
     @pytest.mark.parametrize("packages", [["dep"], ["dep", "another-dep"], ["channel::dep"]])
-    def test_remove(self, core, project, mock_conda, conda_response, packages):
-        self.test_add(core, project, mock_conda, conda_response, packages, None, None)
+    @pytest.mark.parametrize("conda_mapping", CONDA_MAPPING)
+    def test_remove(self, core, project, mock_conda, conda_response, packages, mock_conda_mapping):
+        self.test_add(core, project, mock_conda, conda_response, packages, None, None, mock_conda_mapping)
         mock_conda.reset_mock()
         core.main(["remove", "--no-self"] + packages, obj=project)
         conda_calls = len(conda_response) - len(PYTHON_REQUIREMENTS)
         cmd_order = []
         if conda_calls:
-            cmd_order = ["list"] + ["search"] * len(PYTHON_REQUIREMENTS) + ["remove"] * conda_calls
+            cmd_order = ["list"] + ["remove"] * conda_calls
         assert mock_conda.call_count == len(cmd_order)
         packages = [p["name"] for p in conda_response]
         python_packages = [f"{p['name']}=={p['version']}" for p in PYTHON_REQUIREMENTS]
