@@ -1,6 +1,11 @@
 import pytest
 
-from tests.conftest import CONDA_INFO, PYTHON_REQUIREMENTS
+from tests.conftest import (
+    CONDA_INFO,
+    CONDA_MAPPING,
+    PYTHON_REQUIREMENTS,
+    PYTHON_VERSION,
+)
 
 
 class TestLock:
@@ -10,7 +15,18 @@ class TestLock:
     @pytest.mark.parametrize("empty_conda_list", [False])
     @pytest.mark.parametrize("group", ["default", "dev", None])
     @pytest.mark.parametrize("add_conflict", [True, False])
-    def test_lock(self, core, project, mock_conda, conda_response, group, add_conflict, refresh=False):
+    @pytest.mark.parametrize("conda_mapping", CONDA_MAPPING)
+    def test_lock(
+        self,
+        core,
+        project,
+        mock_conda,
+        conda_response,
+        group,
+        add_conflict,
+        mock_conda_mapping,
+        refresh=False,
+    ):
         """
         Test lock command work as expected
         """
@@ -19,22 +35,14 @@ class TestLock:
         python_requirements = {c["name"] for c in PYTHON_REQUIREMENTS}
         conda_response = [c for c in conda_response if c["name"] not in python_requirements]
         package = conda_response[1]["name"]
-        project.pyproject._data.update(
-            {
-                "tool": {
-                    "pdm": {
-                        "conda": {
-                            "runner": self.conda_runner,
-                            "dependencies": [package],
-                        },
-                    },
-                },
-            },
-        )
+        config = project.conda_config
+        config.runner = self.conda_runner
+        config.dependencies = [package]
         if add_conflict:
+            package = conda_response[0]["name"]
             project.pyproject._data.update(
                 {
-                    "project": {"dependencies": [conda_response[0]["name"]], "requires-python": ">=3.10"},
+                    "project": {"dependencies": [package], "requires-python": f"=={PYTHON_VERSION}"},
                 },
             )
 
@@ -48,17 +56,25 @@ class TestLock:
         packages_to_search = set(requirements)
         # not all packages conda managed so run pre_lock
         if add_conflict:
-            cmd_order = ["create", "install", "remove"]
+            cmd_order = ["list", "create", "install", "remove"]
             packages_to_search.add(conda_response[0]["name"])
         cmd_order.append("info")
         for c in conda_response:
             for d in c["depends"]:
-                packages_to_search.add(d.replace(" ", ""))
-        cmd_order.extend(["search"] * len(packages_to_search))
+                if not d.startswith("python "):
+                    packages_to_search.add(d.replace(" ", ""))
+        if packages_to_search:
+            for c in PYTHON_REQUIREMENTS:
+                packages_to_search.add(f"{c['name']}=={c['version']}={c['build_string']}")
+            cmd_order.extend(["search", "list"])
+            cmd_order.extend(["search"] * (len(packages_to_search) - 1))
 
         assert mock_conda.call_count == len(cmd_order)
 
-        requirements.append(f"python=={project.python.version}")
+        python_package = next(filter(lambda p: p["name"] == "python", PYTHON_REQUIREMENTS))
+        requirements.append(
+            f"channel::{python_package['name']}=={python_package['version']}={python_package['build_string']}",
+        )
         for (cmd,), kwargs in mock_conda.call_args_list:
             assert cmd[0] == self.conda_runner
             cmd_subcommand = cmd[1]
@@ -74,12 +90,21 @@ class TestLock:
         lockfile = project.lockfile
         packages = lockfile["package"]
         for p in packages:
-            name = p["name"]
-            assert name in packages_to_search
+            assert p["name"] in packages_to_search
 
     @pytest.mark.parametrize("conda_response", CONDA_INFO)
     @pytest.mark.parametrize("empty_conda_list", [False])
     @pytest.mark.parametrize("group", ["default", "dev", None])
-    def test_lock_refresh(self, core, project, mock_conda, conda_response, group):
-        self.test_lock(core, project, mock_conda, conda_response, group, False)
-        self.test_lock(core, project, mock_conda, conda_response, group, False, refresh=True)
+    @pytest.mark.parametrize("conda_mapping", CONDA_MAPPING)
+    def test_lock_refresh(self, core, project, mock_conda, conda_response, group, mock_conda_mapping):
+        self.test_lock(core, project, mock_conda, conda_response, group, False, mock_conda_mapping)
+        self.test_lock(
+            core,
+            project,
+            mock_conda,
+            conda_response,
+            group,
+            False,
+            mock_conda_mapping,
+            refresh=True,
+        )
